@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -155,14 +155,14 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 162 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 162 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 164 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 164 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 169 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 169 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -175,7 +175,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 185 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -523,9 +523,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 533 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 533 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 535 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -570,7 +570,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 582 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 582 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -710,6 +710,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -738,6 +739,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -747,11 +751,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -837,7 +844,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 854 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 861 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -856,9 +863,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 874 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 881 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 881 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 888 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1220,15 +1227,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1621 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 1628 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2038 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2045 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2239 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2246 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2333 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2340 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2336 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2343 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1496,15 +1503,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2606 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2613 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2674 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2681 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2700 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2707 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2720 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2727 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2728 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2735 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1528,7 +1535,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2757 "/builds/moz2_slave/rel-191-xr-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2764 "/builds/slave/191-lnx-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
